@@ -36,6 +36,10 @@ class DependencyInfo(BaseModel):
     fields: T.Set[str]
     ignore_if_admin: bool
     ignore_if_no_auth_id: bool
+    require_user: bool
+
+
+FieldDepMapAlias = T.Dict[str, DependencyInfo]
 
 
 class Resolver(BaseModel, T.Generic[NodeType]):
@@ -43,7 +47,7 @@ class Resolver(BaseModel, T.Generic[NodeType]):
 
     _node: T.ClassVar[T.Type[NodeType]]
     _edge_resolver_map: T.ClassVar[T.Dict[str, EdgeResolverType]]
-    _field_dependency_map: T.ClassVar[T.Dict[str, DependencyInfo]]
+    _field_dependency_map: T.ClassVar[FieldDepMapAlias]
 
     _filter: str = PrivateAttr(None)
     _order_by: str = PrivateAttr(None)
@@ -64,13 +68,36 @@ class Resolver(BaseModel, T.Generic[NodeType]):
 
     """PROPERTIES"""
 
+    @classmethod
+    def set_field_dependency_map(cls, field_dep_map: FieldDepMapAlias) -> None:
+        cls._field_dependency_map = field_dep_map
+
     @classmethod
     @property
-    def field_dependency_map(cls) -> T.Dict[str, DependencyInfo]:
+    def field_dependency_map(cls) -> FieldDepMapAlias:
         if getattr(cls, "_field_dependency_map", None) is None:
-            cls._field_dependency_map = dict()
+            cls.set_field_dependency_map(dict())
         return cls._field_dependency_map
 
+    @classmethod
+    def upsert_dependency_info(cls, field: str, dep_info: DependencyInfo) -> None:
+        if getattr(cls, "_field_dependency_map", None) is None:
+            cls.set_field_dependency_map(dict())
+        prev_dep_info: DependencyInfo = cls._field_dependency_map.get(field)
+        if prev_dep_info:
+            prev_dep_info.fields.update(dep_info.fields)
+            prev_dep_info.require_user = (
+                prev_dep_info.require_user or dep_info.require_user
+            )
+            prev_dep_info.ignore_if_admin = (
+                prev_dep_info.ignore_if_admin and dep_info.ignore_if_admin
+            )
+            prev_dep_info.ignore_if_no_auth_id = (
+                prev_dep_info.ignore_if_no_auth_id and dep_info.ignore_if_no_auth_id
+            )
+        else:
+            cls._field_dependency_map[field] = dep_info
+
     @classmethod
     @property
     def _model_name(cls) -> str:
